@@ -1,4 +1,4 @@
-#!/usr/bin/perl
+#!/usr/bin/perl 
 #
 # viperdb.pl - Filesystem Integrity Monitor
 #
@@ -9,8 +9,10 @@
 # as published by the Free Software Foundation; either version 2
 # of the License, or (at your option) any later version.
 
-# This is the only thing you should need to set
-$configfile='/usr/local/etc/viperdb.ini';
+# These are the only things you should need to set
+$configfile='/usr/local/etc/viperdb.conf';
+$notifymail='Y';
+$notify_email='root';
 
 ###
 ### You shouldn't have to touch anything below here
@@ -24,8 +26,8 @@ if (@ARGV[0] eq '-init'){
 	print "Check Detected: Now Checking File Sanity...\n";
 	&SysCheck;
 } else {
-	print "\n\nViperDB v0.7\n";
-	print "ERROR: Unrecoignized option or none given.\n";
+	print "\n\nViperDB v0.8\n";
+	print "ERROR: Unrecognized option or none given.\n";
 	print "usage: ViperDB -init -check\n";
 	print "     -init          Initializes the ViperDB Databases\n";
 	print "     -check         Runs a system file sanity check\n";
@@ -51,6 +53,7 @@ sub SysCheck {
 	# displayed changes, if any, and we are now going
 	# to re-create the database with the new perms.
 	$runtype='init';
+	$recreating='Y';
 	print "Creating New Databases...\n";
 	&CreateDB;
 
@@ -70,6 +73,9 @@ sub CreateDB {
 				if ($runtype eq 'init') {				
 					$ViperDB=$wd . '.ViperDB';
 					$tmpfile='/tmp/.ViperDB';
+					if ($recreating eq 'Y') {
+						system("chattr -iu $ViperDB");
+					}
 				} else {
 					$ViperDB=$wd . '.ViperDB.tmp';
 					$tmpfile='/tmp/.ViperDB.tmp';
@@ -78,7 +84,7 @@ sub CreateDB {
 				# Get a dump of all the current files in the dir and 
 				system("ls -laAS $wd|tr -s ' '|grep -v total|grep -v ViperDB>>$tmpfile");
 
-				open (SUPPAHSEKRETDB, "> $ViperDB");
+				open (VIPERDB, "> $ViperDB");
 		
 					open (BINLIST, "< $tmpfile");
 						$line=<BINLIST>;
@@ -112,20 +118,23 @@ sub CreateDB {
 							# print "Group Perms: $gperms\n";
 							# print "Other Perms: $aperms\n";
 					
-							print SUPPAHSEKRETDB "$wd$bname,$size,$filetype,$uid,$operms,$gid,$gperms,$aperms,$month,$day,$yearortime\n";
+							print VIPERDB "$wd$bname,$size,$filetype,$uid,$operms,$gid,$gperms,$aperms,$month,$day,$yearortime\n";
 	
 							$line=<BINLIST>;
 							chomp $line;
 						} # While
 					close (BINLIST);
-				
-					# rm the tmpfile
+					
+					#rm the tmp db
 					system("rm -rf $tmpfile");
 				
-				close(SUPPAHSEKRETDB);
+				close(VIPERDB);
 				
 				# Change the permissions to only allow root to read...
 				system("chmod 400 $ViperDB");
+				if ($runtype eq 'init') { 
+					system("chattr +iu $ViperDB");
+				}
 				$configline=<CONFIG>;
 				chomp $configline;
 	
@@ -198,31 +207,42 @@ sub Compare {
 							chomp $yearortimeb;
 							if( ! defined($binnameb) ){
 								print LOG "Alert - FILE DELETED: $binnamea\n";
+								$errorsummary .= "Alert - FILE DELETED: $binnamea\n";
 								$trouble++;
 							} else {
 								print LOG "Alert - CHANGES TO FILE: $bname\n";
+								$errorsummary .= "Alert - CHANGES TO FILE: $bname\n";
 								$trouble++;
-									if($sizeb ne $sizea) {
+								
+
+								if($sizeb ne $sizea) {
 									print LOG "Alert - SIZE: was $sizea now $sizeb\n";
+									$errorsummary .= "Alert - SIZE: was $sizea now $sizeb\n";
 								}
 								if($filetypeb ne $filetypea) {
 									print LOG "Alert - TYPE: was $filetypea now $filetypeb\n";
+									$errorsummary .= "Alert - TYPE: was $filetypea now $filetypeb\n";
 								}
 								if($uidb ne $uida) {
 									print LOG "Alert - OWNER: was $uida now $uidb\n";
+									$errorsummary .= "Alert - OWNER: was $uida now $uidb\n";
 									if($strictmode eq 'Y'){
 										print LOG "Alert - OWNER: Changing owner of $bname back to $uida\n";
+										$errorsummary .= "Alert - OWNER: Changing owner of $bname back to $uida";
 										system("chown $uida $bname");
 									}
 								}
 								if($opermsb ne $opermsa) {
 									print LOG "Alert - OWNER PERMS: was $opermsa now $opermsb\n";
+									$errorsummary .= "Alert - OWNER PERMS: was $opermsa now $opermsb";
 									if($strictmode eq 'Y'){
 										if ($opermsa =~ /s/){
 											print LOG "Alert - OWNER PERMS: Change to a SUID file detected - Removing all permissions\n";
+											$errorsummary .= "Alert - OWNER PERMS: Change to a SUID file detected - Removing all permissions";
 											system("chmod 000 $bname");
 										} else {
 											print LOG "Alert - OWNER PERMS: Changing owner perms on $bnamea back to $opermsa\n";
+											$errorsummary .= "Alert - OWNER PERMS: Changing owner perms on $bnamea back to $opermsa\n";
 											$setperms="";
 											if ($opermsa =~ /r/){
 												$setperms = $setperms . "r";
@@ -240,19 +260,24 @@ sub Compare {
 								} # if
 								if($gidb ne $gida) {
 									print LOG "Alert - GROUP: was $gida now $gidb\n";
+									$errorsummary .= "Alert - GROUP: was $gida now $gidb\n";
 									if($strictmode eq 'Y'){
 										print LOG "Alert - GROUP: Changing group of $bname back to $gida\n";
+										$errorsummary .= "Alert - GROUP: Changing group of $bname back to $gida\n";
 										system("chgrp $gida $bname");
 									} # if
 								} # if
 								if($gpermsb ne $gpermsa) {
 									print LOG "Alert - GROUP PERMS: was $gpermsa now $gpermsb\n";
+									$errorsummary .= "Alert - GROUP PERMS: was $gpermsa now $gpermsb\n";
 									if($strictmode eq 'Y'){
 										if ($opermsa =~ /s/){
 											print LOG "Alert - GROUP PERMS: Change to a SGID file detected - Removing all permissions\n";
+											$errorsummary .= "Alert - GROUP PERMS: Change to a SGID file detected - Removing all permissions\n";
 											system("chmod 000 $bname");
 										} else {
 											print LOG "Alert - GROUP PERMS: Changing group perms on $bnamea back to $gpermsa\n";
+											$errorsummary .= "Alert - GROUP PERMS: Changing group perms on $bnamea back to $gpermsa\n";
 											$setperms="";
 											if ($gpermsa =~ /r/){
 												$setperms = $setperms . "r";
@@ -270,8 +295,10 @@ sub Compare {
 								} # if 
 								if($apermsb ne $apermsa) {
 									print LOG "Alert - ALL PERMS: was $apermsa now $apermsb\n";
+									$errorsummary .= "Alert - ALL PERMS: was $apermsa now $apermsb\n";
 									if($strictmode eq 'Y'){
 										print LOG "Alert - ALL PERMS: Changing ALL perms on $bnamea back to $apermsa\n";
+										$errorsummary .= "Alert - ALL PERMS: Changing ALL perms on $bnamea back to $apermsa\n";
 										$setperms="";
 										if ($apermsa =~ /r/){
 											$setperms = $setperms . "r";
@@ -288,6 +315,7 @@ sub Compare {
 								} # if
 								if($monthb ne $montha || $dayb ne $daya || $yearortimeb ne $yearortimea) {
 									print LOG "Alert - TIMESTAMP: was $montha $daya $yearortimea now $monthb $dayb $yearortimeb\n";
+									$errorsummary .= "Alert - TIMESTAMP: was $montha $daya $yearortimea now $monthb $dayb $yearortimeb\n";
 								} # if 
 							} # if ... else
 						} # if
@@ -300,6 +328,7 @@ sub Compare {
 						($binnameb,$junk) = split/,/,$fileinfob;
 						if (! defined($binnamea) ) {
 							print LOG "Alert - NEW FILE: $binnameb\n";
+							$errorsummary .= "Alert - NEW FILE: $binnameb\n";
 							$trouble=$trouble+1;
 						} # if
 					} # foreach
@@ -307,9 +336,15 @@ sub Compare {
 			chomp $dirlistline;
 		} # While
 	if ($trouble!=0) {
-		 print LOG "Info - END RUN - $trouble changes detected.";
+		print LOG "Info - END RUN - $trouble changes detected.";
+		$errorsummary .= "Info - END RUN - $trouble changes detected.";
 	} # if
 	close (LOG);
+	if ($notifymail eq 'Y' && $trouble != 0) { 
+		open (MAIL, "|mail $notify_email");
+			print MAIL "$errorsummary";
+		close(MAIL);
+	} #if
 } # sub
 
 sub Cleanup {
